==> v1.4.0.tar.gz: contentdb/app/flatpages/policy_and_guidance.md <==
title: Package Inclusion Policy and Guidance

<div class="box box_grey alert alert-warning">
	<b>Note:</b> This is a draft
</div>

## 1. General

It is not permitted to submit abusive, obscene, vulgar, slanderous, hateful,
threatening, sexually-orientated or any material that may violate any laws be
it of your country, the country where "Content DB” is hosted or International Law.

The ContentDB admin reserves the right to remove packages for any reason,
including ones not covered by this document, and to ban users who abuse this service.

Also see the [help page on tags](/help/package_tags/).


## 2. State of Completion

ContentDB should only currently contain playable content, ie: stuff that would
be in Mod Releases and Game Releases. Please don't upload any Work In Progress (WIP)
things.

This will probably change in future.


## 3. Technical Names

### 3.1 Right to a name

The first package to use a name based on the creation of its forum topic or
contentdb submission has the right to the technical name. The use of a package
on a server or in private doesn't reserve its name. No other packages of the same
type may use the same name, except for the exception given by 2.2.

If it turns out that we made a mistake by approving a package and that the
name should have been given to another package, then we *may* unapprove the
package and give the name to the correct one.

If you submit a package where you don't have the right to the name you will be asked
to change the name of the package, or your package won't be accepted.

### 3.2 Mod Forks and Reimplementations

An exception to the above is that mods are allowed to have the same name as a
mod if its a fork of that mod (or a close reimplementation). In real terms, it
should be possible to use the new mod as a drop-in replacement.

We reserve the right to decide whether a mod counts as a fork or
reimplementation of the mod that owns the name.


## 4. Licenses

### 4.1 Allowed Licenses

Please ensure that you correctly credit any resources (code, assets, or otherwise)
that you have used in your package.

**The use of licenses which do not allow derivatives or redistribution is not
permitted. This includes CC-ND (No-Derivatives) and lots of closed source licenses.**

However, closed sourced licenses are allowed if they allow the above.

If the license you use is not on the list then please choose the correct "Other"
option.

Please note that the definitions of "free" and "non-free" is the same as that
of the [Free Software Foundation](https://www.gnu.org/philosophy/free-sw.en.html).

### 4.2 Recommended Licenses

It is recommended that you use a proper license for code with a warranty
disclaimer, such as the (L)GPL or MIT. You should also use a proper media license
for media, such as a Creative Commons license.

The use of WTFPL is discouraged as it doesn't contain a valid warranty disclaimer,
and also includes swearing which dissuades teachers from using your content.

Public domain is not a valid license in many countries, please use CC0 or MIT instead.


## 5. Advertisements (inc. asking for donations)

Any other information than the long description - including screenshots - must
not contain any promotions or advertisements. This includes asking for donations
or promoting online market stores.

Paid promotions are not allowed at all, anywhere.


## 6. Reporting Violations

See the [Reporting Content](/help/reporting/) page.

==> v1.7.1.tar.gz: contentdb/app/flatpages/policy_and_guidance.md <==
title: Package Inclusion Policy and Guidance

<div class="box box_grey alert alert-warning">
	<b>Note:</b> This is a draft
</div>

## 1. General

It is not permitted to submit abusive, obscene, vulgar, slanderous, hateful,
threatening, sexually-orientated or any material that may violate any laws be
it of your country, the country where "Content DB” is hosted or International Law.

The ContentDB admin reserves the right to remove packages for any reason,
including ones not covered by this document, and to ban users who abuse this service.

Also see the [help page on tags](/help/package_tags/).


## 2. Accepted Content and State of Completion

The submission of malware is strictly prohibited. This includes software which
does not do as it advertises, for example if it posts telemetry without stating
clearly that it does in the package meta.

ContentDB should only currently contain playable content, ie: stuff that would
be in Mod Releases and Game Releases. Please don't upload any Work In Progress (WIP)
things. This will probably change in future if/when an "early access" feature is
added.

Adding non-player facing mods, such as libraries and server tools, is perfectly fine.
ContentDB isn't just for player-facing things, and adding libraries allows them to be
installed when a mod depends on it.


## 3. Technical Names

### 3.1 Right to a name

The first package to use a name based on the creation of its forum topic or
contentdb submission has the right to the technical name. The use of a package
on a server or in private doesn't reserve its name. No other packages of the same
type may use the same name, except for the exception given by 2.2.

If it turns out that we made a mistake by approving a package and that the
name should have been given to another package, then we *may* unapprove the
package and give the name to the correct one.

If you submit a package where you don't have the right to the name you will be asked
to change the name of the package, or your package won't be accepted.

### 3.2 Mod Forks and Reimplementations

An exception to the above is that mods are allowed to have the same name as a
mod if its a fork of that mod (or a close reimplementation). In real terms, it
should be possible to use the new mod as a drop-in replacement.

We reserve the right to decide whether a mod counts as a fork or
reimplementation of the mod that owns the name.


## 4. Licenses

### 4.1 Allowed Licenses

Please ensure that you correctly credit any resources (code, assets, or otherwise)
that you have used in your package.

**The use of licenses which do not allow derivatives or redistribution is not
permitted. This includes CC-ND (No-Derivatives) and lots of closed source licenses.**

However, closed sourced licenses are allowed if they allow the above.

If the license you use is not on the list then please choose the correct "Other"
option.

Please note that the definitions of "free" and "non-free" is the same as that
of the [Free Software Foundation](https://www.gnu.org/philosophy/free-sw.en.html).

### 4.2 Recommended Licenses

It is recommended that you use a proper license for code with a warranty
disclaimer, such as the (L)GPL or MIT. You should also use a proper media license
for media, such as a Creative Commons license.

The use of WTFPL is discouraged as it doesn't contain a valid warranty disclaimer,
and also includes swearing which dissuades teachers from using your content.

Public domain is not a valid license in many countries, please use CC0 or MIT instead.


## 5. Promotions and Advertisements (inc. asking for donations)

Any information other than the long description - including screenshots - must
not contain any promotions or advertisements. This includes asking for donations,
promoting online shops, or linking to personal websites and social media.

ContentDB is for the community. We may remove any promotions if we feel that
they're inappropriate.

Paid promotions are not allowed at all, anywhere.


## 6. Reporting Violations

See the [Reporting Content](/help/reporting/) page.
